@@ -1,11 +1,10 @@
 import sys
 import time
-import subprocess
 from socket import gethostbyname
 
 from wiperf_poller.helpers.wirelessadapter import WirelessAdapter
 from wiperf_poller.testers.mgtconnectiontester import MgtConnectionTester
-from wiperf_poller.helpers.route import check_correct_mode_interface
+from wiperf_poller.helpers.route import check_correct_mode_interface, inject_default_route
 
 class WirelessConnectionTester(object):
     """
@@ -21,23 +20,23 @@ class WirelessConnectionTester(object):
     def run_tests(self, watchdog_obj, lockf_obj, config_vars, exporter_obj):
 
         # if we have no network connection (i.e. no bssid), no point in proceeding...
-        self.file_logger.info("Checking wireless connection available.")
+        self.file_logger.info("  Checking wireless connection available.")
         if self.adapter_obj.get_wireless_info() == False:
 
-            self.file_logger.error("Unable to get wireless info due to failure with ifconfig command")
+            self.file_logger.error("  Unable to get wireless info due to failure with ifconfig command")
             watchdog_obj.inc_watchdog_count()
             self.adapter_obj.bounce_error_exit(lockf_obj)  # exit here
 
-        self.file_logger.info("Checking we're connected to the network")
+        self.file_logger.info("Checking we're connected to the network (layer3)")
         if self.adapter_obj.get_bssid() == 'NA':
-            self.file_logger.error("Problem with wireless connection: not associated to network")
+            self.file_logger.error("  Problem with wireless connection: not associated to network")
             watchdog_obj.inc_watchdog_count()
             self.adapter_obj.bounce_error_exit(lockf_obj)  # exit here
 
-        self.file_logger.info("Checking we have an IP address.")
+        self.file_logger.info("  Checking we have an IP address.")
         # if we have no IP address, no point in proceeding...
         if self.adapter_obj.get_adapter_ip() == False:
-            self.file_logger.error("Unable to get wireless adapter IP info")
+            self.file_logger.error("  Unable to get wireless adapter IP info")
             watchdog_obj.inc_watchdog_count()
             self.adapter_obj.bounce_error_exit(lockf_obj)  # exit here
 
@@ -49,18 +48,17 @@ class WirelessConnectionTester(object):
         '''
 
         if self.adapter_obj.get_ipaddr() == 'NA':
-            self.file_logger.error("Problem with wireless connection: no valid IP address")
+            self.file_logger.error("  Problem with wireless connection: no valid IP address")
             watchdog_obj.inc_watchdog_count()
             self.adapter_obj.bounce_error_exit(lockf_obj) # exit here
 
         # final connectivity check: see if we can resolve an address
         # (network connection and DNS must be up)
-        self.file_logger.info("Checking we can do a DNS lookup to {}".format(config_vars['connectivity_lookup']))
+        self.file_logger.info("  Checking we can do a DNS lookup to {}".format(config_vars['connectivity_lookup']))
         try:
             gethostbyname(config_vars['connectivity_lookup'])
         except Exception as ex:
-            self.file_logger.error(
-                "DNS seems to be failing, bouncing wireless interface. Err msg: {}".format(ex))
+            self.file_logger.error("  DNS seems to be failing, bouncing wireless interface. Err msg: {}".format(ex))
             watchdog_obj.inc_watchdog_count()
             self.adapter_obj.bounce_error_exit(lockf_obj)  # exit here
         
@@ -68,11 +66,20 @@ class WirelessConnectionTester(object):
         ip_address = gethostbyname(config_vars['connectivity_lookup'])
         if not check_correct_mode_interface(ip_address, config_vars, self.file_logger):
 
-            self.file_logger.error("We are not using the interface required to perform our tests due to a routing issue in this unit.")
-            self.file_logger.error("Suggest making static routing additions or adding an additional metric to the interface causing the issue.")
-            self.file_logger.error("Exiting.")
-            lockf_obj.delete_lock_file()
-            sys.exit()
+            self.file_logger.warning("  We are not using the interface required to perform our tests due to a routing issue in this unit - attempt route addition to fix issue")
+            
+            if inject_default_route(config_vars['connectivity_lookup'], config_vars, self.file_logger):
+            
+                self.adapter_obj.bounce_wlan_interface()
+                self.file_logger.info("  Checking if route injection worked...")
+
+                if check_correct_mode_interface(ip_address, config_vars, self.file_logger):
+                    self.file_logger.info("  Routing issue corrected OK.")
+                else:
+                    self.file_logger.warning("  We still have a routing issue. Will have to exit as testing over correct interface not possible")
+                    self.file_logger.warning("  Suggest making static routing additions or adding an additional metric to the interface causing the issue.")
+                    lockf_obj.delete_lock_file()
+                    sys.exit()
 
         # Check we can get to the mgt platform (function will exit script if no connectivity)
         self.file_logger.info("Checking we can get to the management platform...")
@@ -103,7 +110,8 @@ class WirelessConnectionTester(object):
         results_dict['location'] = config_vars['location']
 
         # dump out adapter info to log file
-        self.file_logger.info("Wireless connection: SSID:{}, BSSID:{}, Freq:{}, Center Freq:{}, Channel: {}, Channel Width: {}, Tx Phy rate:{}, \
+        self.file_logger.info("########## Wireless Connection ##########")
+        self.file_logger.info("Wireless connection data: SSID:{}, BSSID:{}, Freq:{}, Center Freq:{}, Channel: {}, Channel Width: {}, Tx Phy rate:{}, \
             Rx Phy rate:{}, Tx MCS: {}, Rx MCS: {}, RSSI:{}, Tx retries:{}, IP address:{}".format(
             results_dict['ssid'], results_dict['bssid'], results_dict['freq_ghz'], results_dict['center_freq_ghz'], results_dict['channel'], 
             results_dict['channel_width'],  results_dict['tx_rate_mbps'], results_dict['rx_rate_mbps'], results_dict['tx_mcs'],
